@@ -18,6 +18,9 @@ autotyp.feature <-
   function(features,
            na.rm = TRUE,
            glottolog.source = "modified") {
+    message("Don't forget to cite a source:
+
+Bickel, Balthasar, Johanna Nichols, Taras Zakharko, Alena Witzlack-Makarevich, Kristine Hildebrandt, Michael Rie\u00DFler, Lennart Bierkandt, Fernando Z\u00FA\u00F1iga & John B. Lowe. 2017. The AUTOTYP typological databases. Version 0.1.0 https://github.com/autotyp/autotyp-data/tree/0.1.0")
     features <- gsub(" ", "_", features)
     features_set <-
       c(
@@ -104,4 +107,4 @@ autotyp.feature <-
       ))
     }
     return(final_df)
-  }
+    }
