@@ -625,6 +625,9 @@ sails.feature <-
         "TAME4-6",
         "TAME4-7"
       )
+    message("Don't forget to cite a source (modify in case of using individual chapters):
+
+Muysken, Pieter, Harald Hammarstr\u00D6m, Olga Krasnoukhova, Neele M\u00DCller, Joshua Birchall, Simon van de Kerke, Loretta O'Connor, Swintha Danielsen, Rik van Gijn & George Saad. 2016. South American Indigenous Language Structures (SAILS) Online. Leipzig: Online Publication of the Max Planck Institute for Evolutionary Anthropology. (Available at http://sails.clld.org)")
     if (sum(!toupper(features) %in% features_set) < 1) {
       links <-
         paste0("http://sails.clld.org/parameters/",
